pub struct Sequence {
pub id: i64,
pub external_id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub asset_id: Option<i64>,
pub metadata: Option<HashMap<String, String>>,
pub columns: Vec<SequenceColumn>,
pub created_time: i64,
pub last_updated_time: i64,
pub data_set_id: Option<i64>,
}Expand description
A CDF sequence.
Fields
id: i64Sequence internal ID.
external_id: Option<String>External ID of the sequence. Must be unique within the project.
name: Option<String>Name of the sequence.
description: Option<String>Description of the sequence.
asset_id: Option<i64>ID of asset this sequence belongs to.
metadata: Option<HashMap<String, String>>Custom, application specific metadata. String key -> String value. Maximum length of key is 128 bytes, up to 256 key-value pairs, up to a total size of 10000 bytes across all keys and values.
columns: Vec<SequenceColumn>List of columns in this sequence.
created_time: i64Time this sequence was created, in milliseconds since epoch.
last_updated_time: i64Time this sequence was last updated, in milliseconds since epoch.
data_set_id: Option<i64>ID of the data set this sequence belongs to.